@@ -4,7 +4,7 @@ Gallery syndication feeds.
 
 from django.contrib.syndication.views import Feed
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from .models import Gallery
 
