@@ -5,7 +5,7 @@ from django.contrib.postgres.fields import ArrayField, HStoreField
 from django.db import connection, models
 from django.db.models.query import QuerySet
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from markitup.fields import MarkupField
 from model_utils import Choices
