@@ -1,15 +1,10 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) Zbigniew Siciarz 2012-2014.
-
-from __future__ import unicode_literals
-
 from django.contrib.sitemaps import Sitemap
 
 from .models import Gallery, Photo
 
 
 class GallerySitemap(Sitemap):
-    changefreq = 'weekly'
+    changefreq = "weekly"
     priority = 0.5
 
     def items(self):
@@ -20,7 +15,7 @@ class GallerySitemap(Sitemap):
 
 
 class PhotoSitemap(Sitemap):
-    changefreq = 'weekly'
+    changefreq = "weekly"
     priority = 0.5
 
     def items(self):
