@@ -1,4 +1,4 @@
-from django.conf.urls import url
+from django.urls import re_path
 
 from .feeds import GalleryFeed
 from .views import (
@@ -14,30 +14,30 @@ from .views import (
 app_name = "pgallery"
 
 urlpatterns = [
-    url(regex=r"^$", view=GalleryListView.as_view(), name="gallery_list"),
-    url(regex=r"^rss/$", view=GalleryFeed(), name="gallery_rss"),
-    url(
-        regex=r"^photo/(?P<pk>\d+)/$",
+    re_path(route=r"^$", view=GalleryListView.as_view(), name="gallery_list"),
+    re_path(route=r"^rss/$", view=GalleryFeed(), name="gallery_rss"),
+    re_path(
+        route=r"^photo/(?P<pk>\d+)/$",
         view=PhotoDetailsView.as_view(),
         name="photo_details",
     ),
-    url(
-        regex=r"^tag/(?P<tag>[ \w]+)/$",
+    re_path(
+        route=r"^tag/(?P<tag>[ \w]+)/$",
         view=TaggedPhotoListView.as_view(),
         name="tagged_photo_list",
     ),
-    url(
-        regex=r"^exif/(?P<exif_key>[ \w]+)/(?P<exif_value>.+)/$",
+    re_path(
+        route=r"^exif/(?P<exif_key>[ \w]+)/(?P<exif_value>.+)/$",
         view=ExifPhotoListView.as_view(),
         name="exif_photo_list",
     ),
-    url(
-        regex=r"^(?P<slug>[-\w]+)/$",
+    re_path(
+        route=r"^(?P<slug>[-\w]+)/$",
         view=GalleryDetailsView.as_view(),
         name="gallery_details",
     ),
-    url(
-        regex=r"^(?P<year>\d{4})/(?P<month>\d+)/$",
+    re_path(
+        route=r"^(?P<year>\d{4})/(?P<month>\d+)/$",
         view=GalleryMonthArchiveView.as_view(),
         name="month_archive",
     ),
